@@ -1,5 +1,8 @@
 from .get_updates_handler import GetUpdatesAsyncDispatcher
-from .redis_pubsub_handler import RedisPubSubAsyncDispatcher
+try:
+	from .redis_pubsub_handler import RedisPubSubAsyncDispatcher
+except ImportError:
+	pass
 
 __all__ = [
 	'GetUpdatesAsyncDispatcher',
